Wrapper function that generates a data dictionary for all data files in the package with clear step messaging.
Usage
generate(
chat = NULL,
context = NULL,
overwrite = FALSE,
base_path = NULL,
verbose = TRUE,
...
)Examples
if (FALSE) { # \dontrun{
# Without an LLM: produces a dictionary skeleton with empty descriptions.
generate(base_path = "path/to/my-data-package")
# With an LLM: fills in descriptions via ellmer.
chat <- ellmer::chat_openai(model = "gpt-4o-mini")
generate(base_path = "path/to/my-data-package", chat = chat)
} # }